# 9/13/20
# Code is meant to take Cardinal Elo scores and create a set of 
# variables describing 
# 1) time to highest ordinal rank, 
# 2) time at highest ordinal rank, 
# 3) 2-year decline in rank after final loss of top ordinal rank
# 4) 5-year decline in rank after final loss of top ordinal rank

# ==================== TOP ==================================

library(dplyr)
library(lubridate)
library(gombedatabase)
library(ggplot2)

getwd()

discr_vars = read.csv("anon_discrete_vars.csv", header = T)

# -------------- discrete vars & DOM --------------------------

# start elo vs Dom:

discr_vars %>% filter(start_age == 12) %>% pull(start_elo_card) %>% hist()

# Dom and Elo score at entry:
discr_vars %>%
  filter(start_age == 12) %>%
  ggplot(aes(x = resid_dominance_new, y = start_elo_card)) +
  geom_point() + 
  geom_smooth(method = "lm")

discr_vars %>%
  filter(start_age == 12) %>% dim()

discr_vars %>%
  filter(start_age == 12) %>%
  lm(start_elo_card ~ resid_dominance_new, data = .) %>%
  tab_model(digits = 3)

# no Pax:
discr_vars %>%
  filter(start_age == 12, id != "m_79") %>%
  lm(start_elo_card ~ resid_dominance_new, data = .) %>%
  tab_model(digits = 3)




# elo rise vs Dom:

discr_vars %>%
  filter(start_age == 12) %>%
  ggplot(aes(x = resid_dominance_new, y = elo_rise_slope)) +
  geom_point() + 
  geom_smooth(method = "lm")

discr_vars %>%
  filter(start_age == 12) %>%
  lm(elo_rise_slope ~ resid_dominance_new, data = .) %>%
  tab_model(digits = 3)


# highest Elo vs Dom

discr_vars %>% 
  filter(end_age > 26) %>%
  ggplot(aes(x = resid_dominance_new, y = highest_elo_card, color = id == "m_79")) +
  geom_point()

discr_vars %>% 
  filter(end_age > 26) %>% dim()

discr_vars %>% 
  filter(end_age > 26) %>%
  lm(highest_elo_card ~ resid_dominance_new, data = .) %>%
  tab_model(digits = 3)

# no pax
discr_vars %>% 
  filter(end_age > 26, id != "m_79") %>%
  lm(highest_elo_card ~ resid_dominance_new, data = .) %>%
  tab_model(digits = 3)

# Dom vs highest ordinal rank

discr_vars %>% 
  filter(end_age > 26) %>%
  ggplot(aes(x = resid_dominance_new, y = highest_elo_ord, color = id == "m_79")) +
  geom_point() + scale_y_reverse()

discr_vars %>% 
  filter(end_age > 26) %>%
  lm(highest_elo_ord ~ resid_dominance_new, data = .) %>%
  tab_model(digits = 3)
# no pax
discr_vars %>% 
  filter(end_age > 26, id != "m_79") %>%
  lm(highest_elo_ord ~ resid_dominance_new, data = .) %>%
  tab_model(digits = 3)

# time at top rank

discr_vars %>%
  filter(highest_elo_ord <=2) %>%
  mutate(highest_elo_ord = factor(highest_elo_ord)) %>%
  ggplot(aes(x = resid_dominance_new, y = years_at_high_elo)) +
  geom_point(aes(color = highest_elo_ord)) + 
  geom_smooth(method = "lm")

discr_vars %>%
  filter(
    highest_elo_ord <=3
    , start_age < 16
    , end_age > 26
    , id != "m_79"
  ) %>%
  mutate(highest_elo_ord = factor(highest_elo_ord)) %>%
  ggplot(aes(x = resid_dominance_new, y = years_at_high_elo)) +
  geom_point(aes(color = highest_elo_ord)) + 
  geom_smooth(method = "lm")

# downward slope:

discr_vars %>%
  ggplot(aes(x = resid_dominance_new, y = two_yr_elo_decline_slope)) +
  geom_point(aes(color = highest_elo_ord))


# no pax
discr_vars %>%
  filter(id != "m_79") %>%
  lm(resid_dominance_new ~ two_yr_elo_decline_slope, data = .) %>%
  summary()

# ----------------- discrete vars and CONSC ---------------------

# start elo vs Consc:

discr_vars %>%
  filter(start_age == 12) %>%
  ggplot(aes(x = resid_conscientiousness, y = start_elo_card)) +
  geom_point() + 
  geom_smooth(method = "lm")

discr_vars %>%
  filter(start_age == 12) %>%
  lm(start_elo_card ~ resid_conscientiousness, data = .) %>%
  tab_model(digits = 3)

# no pax
discr_vars %>%
  filter(start_age == 12, id != "m_79") %>%
  lm(start_elo_card ~ resid_conscientiousness, data = .) %>%
  tab_model(digits = 3)


# elo rise vs Con:

discr_vars %>%
  filter(start_age == 12) %>%
  ggplot(aes(x = resid_conscientiousness, y = elo_rise_slope)) +
  geom_point(aes(color = id == "m_79")) + 
  geom_smooth(method = "lm")

discr_vars %>%
  filter(start_age == 12) %>%
  lm(elo_rise_slope ~ resid_conscientiousness, data = .) %>%
  tab_model(digits = 3)


# highest Elo vs Con

discr_vars %>% 
  filter(end_age > 26) %>%
  ggplot(aes(x = resid_conscientiousness, y = highest_elo_card, color = id == "m_79")) +
  geom_point()

discr_vars %>% 
  filter(end_age > 26) %>%
  lm(highest_elo_card ~ resid_conscientiousness, data = .) %>%
  tab_model(digits = 3)
# no pax
discr_vars %>% 
  filter(end_age > 26, id != "m_79") %>%
  lm(highest_elo_card ~ resid_conscientiousness, data = .) %>%
  tab_model(digits = 3)

# Con vs highest ordinal rank

discr_vars %>% 
  filter(end_age > 26) %>%
  ggplot(aes(x = resid_conscientiousness, y = highest_elo_ord, color = id == "m_79")) +
  geom_point() + scale_y_reverse()

discr_vars %>% 
  filter(end_age > 26) %>%
  lm(highest_elo_ord ~ resid_conscientiousness, data = .) %>%
  summary()

# no pax
discr_vars %>% 
  filter(end_age > 26, id != "m_79") %>%
  lm(highest_elo_ord ~ resid_conscientiousness, data = .) %>%
  summary()

# time at top rank

discr_vars %>%
  filter(highest_elo_ord <=2) %>%
  mutate(highest_elo_ord = factor(highest_elo_ord)) %>%
  ggplot(aes(x = resid_conscientiousness, y = years_at_high_elo)) +
  geom_point(aes(color = highest_elo_ord)) + 
  geom_smooth(method = "lm")

discr_vars %>%
  filter(
    highest_elo_ord <=3
    , start_age < 16
    , end_age > 26
    , id != "m_79"
  ) %>%
  mutate(highest_elo_ord = factor(highest_elo_ord)) %>%
  ggplot(aes(x = resid_conscientiousness, y = years_at_high_elo)) +
  geom_point(aes(color = highest_elo_ord)) + 
  geom_smooth(method = "lm")

discr_vars %>%
  filter(
    highest_elo_ord <=3
    , start_age < 16
    , end_age > 26
    , id != "m_79"
  ) %>%
  lm(resid_conscientiousness ~ years_at_high_elo, data = .) %>%
  tab_model(digits = 3)

discr_vars %>%
  filter(
    highest_elo_ord <=3
    , start_age < 16
    , end_age > 26
    , id != "m_79"
  ) %>% dim()

# downward slope:

discr_vars %>%
  ggplot(aes(x = resid_conscientiousness, y = two_yr_elo_decline_slope)) +
  geom_point(aes(color = highest_elo_ord))

discr_vars %>%
  filter(id != "m_79") %>%
  lm(resid_conscientiousness ~ two_yr_elo_decline_slope, data = .) %>%
  summary()
